@@ -270,4 +270,9 @@ def upload_csv(path, project_id, tag=None):
     }
     if tag:
         source_file_payload['data']['attributes']['tag_name'] = tag
-    make_request('/source_files', json=source_file_payload, headers=headers)
+    r = make_request('/source_files', json=source_file_payload, headers=headers)
+    return json.loads(r.content.decode())['data']["id"]
+
+
+if __name__ == '__main__':
+    pass
